// RW Bumpmaster
// ==============
// Imageboard Retrieval & Archiving Library
// -Part of the RW Foundations suite of libraries

// Filename: ./include/curator/bumpmaster/bumpmaster.hpp
// -Declarations of the baseline RW Bumpmaster sub-library

#pragma once

#include "incls_all.hpp"

namespace rw::curator::bumpmaster {

//------------------------------------------------------------------------------
class Bumpmaster_b : public RW {
 public:
  Bumpmaster_b();                                    // default ctor
  explicit Bumpmaster_b(std::string const& handle);  // tag-parm'd ctor
};

//------------------------------------------------------------------------------
class Bumpmaster : public Bumpmaster_b {
 public:
  Bumpmaster();                                    // default ctor
  explicit Bumpmaster(std::string const& handle);  // tag-parm'd ctor

  inline auto catalog() const -> Catalog& { return catalog_; }
  inline auto page() const -> Page& { return page_; }
  inline auto post() const -> Post& { return post_; }
  inline auto thread() const -> Thread& { return thread_; }
  inline auto waifusearch() const -> Waifusearch& { return waifusearch_; }
  inline auto wired() const -> Wired& { return wired_; }

 private:
  unique_ptr<Catalog_b> _catalog_{make_unique<Catalog_b>("bumpmaster_catalog")};
  unique_ptr<Page_b>    _page_{make_unique<Page_b>("bumpmaster_page")};
  unique_ptr<Post_b>    _post_{make_unique<Post_b>("bumpmaster_post")};
  unique_ptr<Thread_b>  _thread_{make_unique<Thread_b>("bumpmaster_thread")};
  unique_ptr<Waifusearch_b> _waifusearch_{
      make_unique<Waifusearch_b>("bumpmaster_waifusearch")};
  unique_ptr<Wired_b> _wired_{make_unique<Wired_b>("bumpmaster_wired")};

  Catalog&     catalog_{reference_to<Catalog>(_catalog_.get())};
  Page&        page_{reference_to<Page>(_page_.get())};
  Post&        post_{reference_to<Post>(_post_.get())};
  Thread&      thread_{reference_to<Thread>(_thread_.get())};
  Waifusearch& waifusearch_{reference_to<Waifusearch>(_waifusearch_.get())};
  Wired&       wired_{reference_to<Wired>(_wired_.get())};
};

}  // namespace rw::curator::bumpmaster

//    --=^=--

// "______"

// rw_curator_lib.v211127
// Copyright (2021)
// License MIT (Expat) https://opensource.org/licenses/MIT
